@@ -1,9 +1,9 @@
-# $Id: filter.rb 476 2009-06-29 14:56:20Z helixblue $
+# $Id: filter.rb 527 2010-01-24 19:26:12Z helixblue $
 require 'cgi'
 
 class Filter
   include Common
-  include Display
+  include Messages
     
   @@sizes = {
     'virtual' => 0,
@@ -146,7 +146,7 @@ class Filter
   def ownerExclude(nick)
     debug "filtering by ownerExclude: #{nick}"
     @waypointHash.delete_if { |wid, values|
-      creator = CGI.UnescapeHTML(@waypointHash[wid]['creator'])
+      creator = CGI.unescapeHTML(@waypointHash[wid]['creator'])
       creator =~ /#{nick}/i
     }
   end
